@@ -132,7 +132,7 @@ if (USE_ENCODE) {
     }
 }
 
-$VERSION = '1.013_01';
+$VERSION = '1.010';
 
 ######## Private Attributes ########
 
@@ -142,7 +142,6 @@ my $FALLBACK_CHARSET = 'UTF-8';
 # This table was initially borrowed from Python email package.
 
 my %CHARSETS = (# input		    header enc body enc output conv
-		'DIN_66003' =>          ['Q',   undef,  undef],
 		'ISO-8859-1' =>		['Q',	'Q',	undef],
 		'ISO-8859-2' =>		['Q',	'Q',	undef],
 		'ISO-8859-3' =>		['Q',	'Q',	undef],
@@ -167,14 +166,6 @@ my %CHARSETS = (# input		    header enc body enc output conv
 		'EUC-JP' =>		['B',	undef,	'ISO-2022-JP'],
 		'SHIFT_JIS' =>		['B',	undef,	'ISO-2022-JP'],
 		'ISO-2022-JP' =>	['B',	undef,	undef],
-		'ISO-2022-JP-1' =>	['B',	undef,	undef],
-		'ISO-2022-JP-2' =>	['B',	undef,	undef],
-		'EUC-JISX0213' =>	['B',	undef,	'ISO-2022-JP-3'],
-		'SHIFT_JISX0213' =>	['B',	undef,	'ISO-2022-JP-3'],
-		'ISO-2022-JP-3' =>	['B',	undef,	undef],
-		'EUC-JIS-2004' =>	['B',	undef,	'ISO-2022-JP-2004'],
-		'SHIFT_JIS-2004' =>	['B',	undef,	'ISO-2022-JP-2004'],
-		'ISO-2022-JP-2004' =>	['B',	undef,	undef],
 		'KOI8-R' =>		['B',	'B',	undef],
 		'TIS-620' =>		['B',	'B',	undef], # cf. Mew
 		'UTF-16' =>		['B',	'B',	undef],
@@ -207,7 +198,6 @@ my %CHARSET_ALIASES = (# unpreferred		preferred
 		       "CP874" =>		"WINDOWS-874",
 		       "CP936" =>		"GBK",
 		       "CP949" =>		"KS_C_5601-1987",
-		       "DIN66003" =>		"DIN_66003",
 		       "EUC-CN" =>		"GB2312",
 		       "HZ" =>			"HZ-GB-2312", # RFC 1842
 		       "KS_C_5601" =>		"KS_C_5601-1987",
@@ -237,10 +227,7 @@ my %ENCODERS = (
 		    'ISO-8859-8-I'=>[['cp1255'], ],     # ditto
 		    'ISO-8859-9' => [['cp1254'], ],     # Encode::Byte
 		    'ISO-8859-13'=> [['cp1257'], ],     # Encode::Byte
-		    'GB2312'     => [
-				     ['gb18030',	'Encode::HanExtra'],
-				     ['cp936'],		# Encode::CN
-				    ],
+		    'GB2312'     => [['cp936'], ],      # Encode::CN
 		    'EUC-JP'     => [
 				     ['eucJP-ascii',	'Encode::EUCJPASCII'],
 				     # ['cp51932',	'Encode::EUCJPMS'],
@@ -256,9 +243,6 @@ my %ENCODERS = (
 		    'SHIFT_JIS'  => [
 				     ['cp932'],		# Encode::JP
 				    ],
-		    'EUC-JISX0213'  => [['euc-jis-2004', 'Encode::JISX0213'], ],
-		    'ISO-2022-JP-3' => [['iso-2022-jp-2004', 'Encode::JISX0213'], ],
-		    'SHIFT_JISX0213'=> [['shift_jis-2004', 'Encode::ShiftJIS2004'], ],
 		    'EUC-KR'     => [['cp949'], ],      # Encode::KR
 		    'BIG5'       => [
 				     # ['big5plus',     'Encode::HanExtra'],
@@ -270,18 +254,14 @@ my %ENCODERS = (
 		    'UTF-8'      => [['utf8'], ],       # Special name on Perl
 		},
 		'STANDARD' => {
-		    'DIN_66003'     => [['din66003', 'Endode::DIN66003'], ],
 		    'ISO-8859-6-E'  => [['iso-8859-6'],],# Encode::Byte
 		    'ISO-8859-6-I'  => [['iso-8859-6'],],# ditto
 		    'ISO-8859-8-E'  => [['iso-8859-8'],],# Encode::Byte
 		    'ISO-8859-8-I'  => [['iso-8859-8'],],# ditto
 		    'GB18030'       => [['gb18030',     'Encode::HanExtra'], ],
-		    'ISO-2022-JP-2' => [['iso-2022-jp-2','Encode::ISO2022JP2'], ],
-		    'EUC-JISX0213'  => [['euc-jisx0213', 'Encode::JISX0213'], ],
-		    'ISO-2022-JP-3' => [['iso-2022-jp-3', 'Encode::JISX0213'], ],
-		    'EUC-JIS-2004'  => [['euc-jis-2004', 'Encode::JISX0213'], ],
-		    'ISO-2022-JP-2004' => [['iso-2022-jp-2004', 'Encode::JISX0213'], ],
-		    'SHIFT_JIS-2004'=> [['shift_jis-2004', 'Encode::ShiftJIS2004'], ],
+		    'EUC-JISX0213'  => [['euc-jisx0213', 'Encode::JIS2K'], ],
+		    'ISO-2022-JP-3' => [['iso-2022-jp-3', 'Encode::JIS2K'], ],
+		    'SHIFT_JISX0213'=> [['shiftjisx0213', 'Encode::JIS2K'], ],
 		    'EUC-TW'        => [['euc-tw',      'Encode::HanExtra'], ],
 		    'HZ-GB-2312'    => [['hz'], ],	# Encode::CN
 		    'TIS-620'       => [['tis620'], ],  # (note*)
@@ -305,12 +285,6 @@ my @ESCAPE_SEQS = (
 		   ["\033(I",	"ISO-2022-JP"],	# ditto (nonstandard)
 		   ["\033\$(D",	"ISO-2022-JP"],	# RFC 2237 (note*)
 		   # Following sequences are less commonly used.
-		   ["\033.A",   "ISO-2022-JP-2"], # RFC 1554
-		   ["\033.F",   "ISO-2022-JP-2"], # ditto
-		   ["\033\$(C", "ISO-2022-JP-2"], # ditto
-		   ["\033\$(O",	"ISO-2022-JP-3"], # JIS X 0213:2000
-		   ["\033\$(P",	"ISO-2022-JP-2004"], # JIS X 0213:2000/2004
-		   ["\033\$(Q",	"ISO-2022-JP-2004"], # JIS X 0213:2004
 		   ["\033\$)C",	"ISO-2022-KR"],	# RFC 1557
 		   ["\033\$)A",	"ISO-2022-CN"], # RFC 1922
 		   ["\033\$A",	"ISO-2022-CN"], # ditto (nonstandard)
@@ -327,8 +301,6 @@ my @ESCAPE_SEQS = (
 
 		# Singlebyte 7-bit sequences
 		   # escape seq, possible charset
-		   ["\033(K",   "DIN_66003"],   # ISO-IR-21
-		   ["\033)K",   "DIN_66003"],   # ditto
 		   ["\033e",	"GSM03.38"],	# ESTI GSM 03.38 (note*)
 		   ["\033\012",	"GSM03.38"],	# ditto
 		   ["\033<",	"GSM03.38"],	# ditto
@@ -350,8 +322,6 @@ $Config = {
     Mapping =>         'EXTENDED',
     Replacement =>     'DEFAULT',
 };
-local @INC = @INC;
-pop @INC if $INC[-1] eq '.';
 eval { require MIME::Charset::Defaults; };
 
 ######## Private Constants ########
@@ -418,12 +388,6 @@ sub new {
 	# And "TIS-620" not known by some versions of Encode (cf.
 	# CPAN RT #20781).
 	$charset = "TIS-620";
-    } elsif ($charset =~ /\biso[-_]8859[-_]8[-_]i$/i) {
-	# workaround: "ISO-8859-8-I" is treated as an alias of "ISO-8859-8"
-	# by Encode (3.18): See the note in
-	# https://encoding.spec.whatwg.org/#legacy-single-byte-encodings
-	# However we'll treat these as separate names for compatibility.
-	$charset = "ISO-8859-8-I";
     } else {
 	$charset = resolve_alias($charset) || $charset
     }
@@ -473,7 +437,8 @@ sub _find_encoder($$) {
 	foreach my $s (@{$spec}) {
 	    ($name, $module) = @{$s};
 	    if ($module) {
-		next unless eval "require $module;";
+		eval "use $module;";
+		next if $@;
 	    }
 	    $encoder = Encode::find_encoding($name);
 	    last if ref $encoder;
@@ -842,7 +807,7 @@ sub _enclen_Q($;$) {
     length($s) + scalar(@o) * 2;
 }
 
-sub _resolve_S($;$) {
+sub _resolve_S($) {
     my $s = shift;
     my $in_body = shift;
     my $e;
@@ -1305,7 +1270,7 @@ Hatuka*nezumi - IKEDA Soji <hatuka(at)nezumi.nu>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2006-2017 Hatuka*nezumi - IKEDA Soji.
+Copyright (C) 2006-2013 Hatuka*nezumi - IKEDA Soji.
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
